@@ -27,7 +27,7 @@ GNATS databases are accessed only by GNATS commands (both public and internal).
 """
 
 __author__  = "Milan Zamazal <pdm@freesoft.cz>"
-__version__ = "$Id: gnats.py,v 1.17 2000/01/22 20:22:26 pdm Exp $"
+__version__ = "$Id: gnats.py,v 1.18 2000/03/05 08:09:44 pdm Exp $"
 __copyright__ = "GNU General Public License, version 2"
 
 
@@ -162,7 +162,7 @@ class Gnats:
         """
         command = self._directory_command ('query-pr')
         try:
-            f = os.popen (command + ' --full %s' % self._protect (str (id)))
+            f = os.popen (command + " --full '%s'" % self._protect (str (id)))
             text = f.read ()
             if len (text) < 40:         # "query-pr: no PRs matched"
                 return None
